@@ -13,6 +13,9 @@
 #include <stdint.h>
 #include <string.h>
 #include <ctype.h>
+
+#include <R.h>
+
 #include "utf8.h"
 #include "str.h"
 #include "strsearch.h"
@@ -25,7 +28,7 @@
 #include "bibformats.h"
 
 // Georgi: removed the include declaration for adsout_journals.c further below
-//         also, removed the 'static' keyword for juornals and njournals in adsout_journals.c
+//         also, removed the 'static' keyword for journals and njournals in adsout_journals.c
 
 //   reason: adsout_journals.c was compiled to .o with the standard Makefile leading to
 //   unnecessary duplication and an warning about unused variable 'njournals' (which is used
@@ -351,7 +354,8 @@ output_4digit_value( char *pos, long long n )
 	char buf[6];
 	n = n % 10000; /* truncate to 0->9999, will fit in buf[6] */
 #ifdef WIN32
-	sprintf( buf, "%I64d", n );
+	// sprintf( buf, "%I64d", n ); // warning: ISO C does not support the 'I' printf flag [-Wformat=]
+	sprintf( buf, "%d", (int)n );
 #else
 	sprintf( buf, "%lld", n );
 #endif
@@ -375,13 +379,16 @@ static char
 initial_ascii( const char *name )
 {
 	int b1, b2;
-
 	if ( isascii( name[0] )  )
 		return name[0];
+	
+	// Georgi: fixing github issue #8
+	//     name[0]+256; doesn't give the expected result
+	//     on platforms where char is unsigned char
+        b1 = (unsigned char)(name[0]); // name[0]+256;
+	b2 = (unsigned char)(name[1]); // name[1]+256;
 
-        b1 = name[0]+256;
-        b2 = name[1]+256;
-
+	// REprintf("b1 = %x, b2 = %x\n", b1, b2);
 	switch( b1 ) {
 
 	case 0xc3:
